aboutsummaryrefslogtreecommitdiff
path: root/include/armnn/backends
diff options
context:
space:
mode:
authorCathal Corbett <cathal.corbett@arm.com>2022-02-25 15:33:28 +0000
committerCathal Corbett <cathal.corbett@arm.com>2022-03-01 11:44:14 +0000
commit5aa9fd7ac6bf8dad576fa4a0a32aa3dae98d11ab (patch)
tree23a3a0d5ca5143924277f34c98d36cf7b99430a7 /include/armnn/backends
parent1fc448ad2455ad31b96a3891f847125a3295d75a (diff)
downloadarmnn-5aa9fd7ac6bf8dad576fa4a0a32aa3dae98d11ab.tar.gz
IVGCVSW-6704 Change the namespace from armnn::profiling to arm::pipe
* Updated ABI version to 29 due to being the first ABI break in 22.05 !android-nn-driver:7226 Signed-off-by: Cathal Corbett <cathal.corbett@arm.com> Change-Id: I9c50007dcd5b5e792757e7bd1213606df5ffec36
Diffstat (limited to 'include/armnn/backends')
-rw-r--r--include/armnn/backends/IBackendInternal.hpp4
-rw-r--r--include/armnn/backends/IWorkload.hpp2
-rw-r--r--include/armnn/backends/Workload.hpp6
-rw-r--r--include/armnn/backends/profiling/IBackendProfiling.hpp22
-rw-r--r--include/armnn/backends/profiling/IBackendProfilingContext.hpp11
5 files changed, 24 insertions, 21 deletions
diff --git a/include/armnn/backends/IBackendInternal.hpp b/include/armnn/backends/IBackendInternal.hpp
index c64150a484..06fa5edde8 100644
--- a/include/armnn/backends/IBackendInternal.hpp
+++ b/include/armnn/backends/IBackendInternal.hpp
@@ -86,8 +86,8 @@ public:
using IWorkloadFactoryPtr = std::unique_ptr<IWorkloadFactory>;
using IBackendContextPtr = std::unique_ptr<IBackendContext>;
/// This is the bridge between backend and backend profiling we'll keep it in the backend namespace.
- using IBackendProfilingContextPtr = std::shared_ptr<armnn::profiling::IBackendProfilingContext>;
- using IBackendProfilingPtr = std::unique_ptr<armnn::profiling::IBackendProfiling>;
+ using IBackendProfilingContextPtr = std::shared_ptr<arm::pipe::IBackendProfilingContext>;
+ using IBackendProfilingPtr = std::unique_ptr<arm::pipe::IBackendProfiling>;
using ILayerSupportSharedPtr = std::shared_ptr<ILayerSupport>;
using IBackendSpecificModelContextPtr = std::shared_ptr<IBackendModelContext>;
diff --git a/include/armnn/backends/IWorkload.hpp b/include/armnn/backends/IWorkload.hpp
index ce3914bc5a..20be01658e 100644
--- a/include/armnn/backends/IWorkload.hpp
+++ b/include/armnn/backends/IWorkload.hpp
@@ -29,7 +29,7 @@ public:
virtual void ExecuteAsync(WorkingMemDescriptor& desc) = 0;
- virtual profiling::ProfilingGuid GetGuid() const = 0;
+ virtual arm::pipe::ProfilingGuid GetGuid() const = 0;
// SupportsTensorHandleReplacement signals that a given workload is capable of
// replacing any of its I/O tensors via ReplaceInput/OutputTensorHandle
diff --git a/include/armnn/backends/Workload.hpp b/include/armnn/backends/Workload.hpp
index 21109480dc..ddcc5a8f0a 100644
--- a/include/armnn/backends/Workload.hpp
+++ b/include/armnn/backends/Workload.hpp
@@ -32,7 +32,7 @@ public:
BaseWorkload(const QueueDescriptor& descriptor, const WorkloadInfo& info)
: m_Data(descriptor),
- m_Guid(profiling::ProfilingService::GetNextGuid())
+ m_Guid(arm::pipe::ProfilingService::GetNextGuid())
{
m_Data.Validate(info);
}
@@ -52,7 +52,7 @@ public:
const QueueDescriptor& GetData() const { return m_Data; }
- profiling::ProfilingGuid GetGuid() const final { return m_Guid; }
+ arm::pipe::ProfilingGuid GetGuid() const final { return m_Guid; }
virtual bool SupportsTensorHandleReplacement() const override
{
@@ -75,7 +75,7 @@ public:
protected:
QueueDescriptor m_Data;
- const profiling::ProfilingGuid m_Guid;
+ const arm::pipe::ProfilingGuid m_Guid;
private:
std::mutex m_AsyncWorkloadMutex;
diff --git a/include/armnn/backends/profiling/IBackendProfiling.hpp b/include/armnn/backends/profiling/IBackendProfiling.hpp
index beb7755741..a04f3c1b99 100644
--- a/include/armnn/backends/profiling/IBackendProfiling.hpp
+++ b/include/armnn/backends/profiling/IBackendProfiling.hpp
@@ -12,10 +12,10 @@
#include <memory>
#include <vector>
-namespace armnn
+namespace arm
{
-namespace profiling
+namespace pipe
{
struct CounterValue
@@ -55,11 +55,13 @@ public:
virtual uint16_t RegisterDevice(const std::string& deviceName,
uint16_t cores = 0,
- const Optional<std::string>& parentCategoryName = EmptyOptional()) = 0;
+ const armnn::Optional<std::string>& parentCategoryName
+ = armnn::EmptyOptional()) = 0;
virtual uint16_t RegisterCounterSet(const std::string& counterSetName,
uint16_t count = 0,
- const Optional<std::string>& parentCategoryName = EmptyOptional()) = 0;
+ const armnn::Optional<std::string>& parentCategoryName
+ = armnn::EmptyOptional()) = 0;
virtual uint16_t RegisterCounter(const uint16_t uid,
const std::string& parentCategoryName,
@@ -68,10 +70,10 @@ public:
double multiplier,
const std::string& name,
const std::string& description,
- const Optional<std::string>& units = EmptyOptional(),
- const Optional<uint16_t>& numberOfCores = EmptyOptional(),
- const Optional<uint16_t>& deviceUid = EmptyOptional(),
- const Optional<uint16_t>& counterSetUid = EmptyOptional()) = 0;
+ const armnn::Optional<std::string>& units = armnn::EmptyOptional(),
+ const armnn::Optional<uint16_t>& numberOfCores = armnn::EmptyOptional(),
+ const armnn::Optional<uint16_t>& deviceUid = armnn::EmptyOptional(),
+ const armnn::Optional<uint16_t>& counterSetUid = armnn::EmptyOptional()) = 0;
virtual ~IRegisterBackendCounters() {}
};
@@ -99,6 +101,6 @@ public:
};
-} // namespace profiling
+} // namespace pipe
-} // namespace armnn \ No newline at end of file
+} // namespace arm \ No newline at end of file
diff --git a/include/armnn/backends/profiling/IBackendProfilingContext.hpp b/include/armnn/backends/profiling/IBackendProfilingContext.hpp
index 77959e959b..2e3df48227 100644
--- a/include/armnn/backends/profiling/IBackendProfilingContext.hpp
+++ b/include/armnn/backends/profiling/IBackendProfilingContext.hpp
@@ -8,9 +8,9 @@
#include <armnn/IRuntime.hpp>
#include <vector>
-namespace armnn
+namespace arm
{
-namespace profiling
+namespace pipe
{
class IBackendProfilingContext
@@ -19,12 +19,13 @@ public:
virtual ~IBackendProfilingContext()
{}
virtual uint16_t RegisterCounters(uint16_t currentMaxGlobalCounterID) = 0;
- virtual Optional<std::string> ActivateCounters(uint32_t capturePeriod, const std::vector<uint16_t>& counterIds) = 0;
+ virtual armnn::Optional<std::string> ActivateCounters(uint32_t capturePeriod, const std::vector<uint16_t>&
+ counterIds) = 0;
virtual std::vector<Timestamp> ReportCounterValues() = 0;
virtual bool EnableProfiling(bool flag) = 0;
virtual bool EnableTimelineReporting(bool flag) = 0;
};
using IBackendProfilingContextUniquePtr = std::unique_ptr<IBackendProfilingContext>;
-} // namespace profiling
-} // namespace armnn \ No newline at end of file
+} // namespace pipe
+} // namespace arm \ No newline at end of file